pub struct RawReceived {
pub data: [u8; 129],
pub channel: u8,
}Available on crate features
ieee802154 and unstable only.Expand description
A raw payload received on some channel
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Fields
data: [u8; 129]Payload
channel: u8Receiver channel