pub struct ReceivedFrame {
pub frame: Frame,
pub channel: u8,
pub rssi: i8,
pub lqi: u8,
}Available on crate features
ieee802154 and unstable only.Expand description
IEEE 802.15.4 MAC frame which has been received
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Fields
frame: FrameFrame
channel: u8Receiver channel
rssi: i8Received Signal Strength Indicator (RSSI)
lqi: u8Link Quality Indication (LQI)